@echo OFF
REM ------------------------------------------------------------------------------------------------------------
REM Script to install on user login process the 'GoToMeeting Outlook Plugin' as silent installation
REM This script aboard if the plugin is installed
REM    or one of the prerequisites are not fulfilled
REM ------------------------------------------------------------------------------------------------------------

REM READ the registry value where the plugin comes from
reg query HKCU\Software\Microsoft\Office\Outlook\Addins\GoToMeetingOutlookCalendarPlugin /v manifest 1>nul 2>&1
REM If the reading was successful we ends the script - the plugin is installed
if NOT ERRORLEVEL 1 (
	echo The 'GoToMeeting Outlook Plugin' is allready installed.
	goto SUCCESSFULEND
	)

REM The Registry entry was not found - test if we can install the plugin
echo Try to install GoToMeeting Outlook Plugin

REM Test if the trusted publishers certificate is available
certutil -store -enterprise TRUSTEDPUBLISHER | findstr /C:"LogMeIn" 1>nul 2>&1
if ERRORLEVEL 1 (
	echo Check Requirements: The LogMeIn certificate was not available in trusted publisher store
	goto END
	)
REM Test if outlook is available (We test for reg keys Outlook use to handle add-ins)
reg query "HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\OUTLOOK.EXE" 1>nul 2>&1
if ERRORLEVEL 1 (
	echo Check Requirements: Outlook is not available on this machine
	goto END
	)
REM Test if the required .Net Framework is installed
reg query "HKLM\SOFTWARE\Microsoft\NET Framework Setup\NDP" | findstr /C:"NDP\v4" 1>nul 2>&1
if ERRORLEVEL 1 (
	echo Check Requirements: We miss the .Net 4 Framework on this machine
	goto END
	)
REM Test if we have the required VSTO installer - The delivered Registry path has to contain \V4 in other case it's the wrong version
reg query "HKLM\SOFTWARE\Wow6432Node\Microsoft\VSTO Runtime Setup" /V InstallerPath /s  | findstr /C:"\v4" 1>nul 2>&1
if ERRORLEVEL 1 (
	REM Check if we run on a 32 Bit machine
	reg query "HKLM\SOFTWARE\Microsoft\VSTO Runtime Setup" /V InstallerPath /s  | findstr /C:"\v4" 1>nul 2>&1
	if ERRORLEVEL 1 (
		echo Check Requirements: We miss the .Net 4 Framework on this machine
		goto END
		)
	)

REM Install the GoToMeeting Outlook Plugin:
REM (With following command you get the path - i use the standard path)
REM reg query "HKLM\SOFTWARE\Wow6432Node\Microsoft\VSTO Runtime Setup" /V InstallerPath /s  | findstr /I /R:"[A-Z]\:\\[\w\x20\\.]*VSTOInstaller.exe" 
set VSTOInstaller=C:\Program Files\Common Files\Microsoft Shared\VSTO\10.0\VSTOInstaller.exe
set PluginURL=https://builds.citrixonlinecdn.com/builds/calendarintegration/outlook/G2M/GoToMeetingOutlookCalendarPlugin.vsto
"%VSTOInstaller%" /install "%PluginURL%" /silent
if ERRORLEVEL 1 (
	echo Install Plugin: Installation was not successfull - Please check the Windows Application log
	goto END
) else (
	echo Install Plugin: Installation was successfull - 'GoToMeeting Outlook Plugin' is now available
)

:SUCCESSFULEND
REM Check if we have to disable the old plugin
reg query "HKCU\Software\Microsoft\Office\Outlook\Addins\G2MAddin.OutlookAddin" /V LoadBehavior | findstr /c:"0x3" 1>nul 2>&1
if NOT ERRORLEVEL 1 (
	echo Disable the 'GoToMeeting COM Addin' from auto load in Outlook
	reg ADD "HKCU\Software\Microsoft\Office\Outlook\Addins\G2MAddin.OutlookAddin" /V LoadBehavior /t REG_DWORD /d 2 /f 1>nul 2>&1
)


REM end of silent installer batch for GoToMeeting 
:END